from setuptools import setup, find_packages

setup(
    name="ub-clean-test",
    version="0.2.1",
    author="pengyeqin",
    author_email="xxbj433@qq.com",
    description="A modular robot balance and control framework",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/ZGhunan/ultra-balance",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
    python_requires=">=3.8",
    install_requires=[
        "numpy>=1.21.0",
        "scipy>=1.7.0",
    ],
)